FTL Core
Core MCP server implementation for building AI agent tools.
Re-exports
pub use gateway::GatewayConfig;pub use gateway::GatewayHandler;pub use gateway::McpGateway;pub use gateway::ToolEndpoint;pub use server::McpServer;pub use tool::Tool;pub use types::JsonRpcRequest;pub use types::JsonRpcResponse;pub use types::ToolError;pub use types::ToolResult;
Modules
Macros
- ftl_
mcp_ gateway - Macro to create a Spin component for the MCP gateway
- ftl_
mcp_ server - Macro to create the main entry point for a tool server